@@ -81,7 +81,8 @@ def main():
     else:
         logging_level = logging.ERROR
 
-    print("\n    InfEngine Manager\n")
+    if not args.version and not args.engine_version:
+        print("\n    InfEngine Manager\n")
 
     server = InfEngineServer(
         root_path=root_path, logging_level=logging_level, enable_logging=enable_logging
@@ -111,10 +112,10 @@ def main():
             print(f"InfServer status: {status}\n")
         elif args.version:
 
-            print(f"    Package version: 0.0.15\n")
+            print(f"0.0.16")
         elif args.engine_version:
 
-            print(f"    {server.version()}\n")
+            print(f"{server.version()}")
         elif args.dl_update:
             print(" * Update data", end="")
             server.update_data(dldata=args.dl_update)
